@@ -4,7 +4,7 @@ use v5.14;
 use warnings;
 use utf8;
 
-our $VERSION = "2.12";
+our $VERSION = "2.13";
 
 use Data::Dumper;
 $Data::Dumper::Sortkeys = 1;
@@ -143,6 +143,7 @@ sub new {
 	padding   => 0,
 	boundary  => '',
 	padchar   => ' ',
+	prefix    => '',
 	ambiguous => 'narrow',
 	margin    => 0,
 	linebreak => $DEFAULT_LINEBREAK,
@@ -430,6 +431,11 @@ sub fold {
 	$folded .= $padding;
     }
 
+    if (length and my $p = $opt{prefix}) {
+	my $s = ref $p eq 'CODE' ? &$p : $p;
+	$_ = $s . $_;
+    }
+
     ($folded . $eol, $_, $width - $room);
 }
 
@@ -517,7 +523,7 @@ Text::ANSI::Fold - Text folding library supporting ANSI terminal sequence and As
 
 =head1 VERSION
 
-Version 2.12
+Version 2.13
 
 =head1 SYNOPSIS
 
@@ -711,6 +717,15 @@ given width.
 
     ansi_fold($text, 80, padding => 1, padchar => '_');
 
+=item B<prefix> => I<string> | I<coderef>
+
+B<prefix> string is inserted before remained string if it is not
+empty.  This is convenient to produce indented series of text by
+B<chops> interface.
+
+If the value is reference to subroutine, its result is used as a
+prefix string.
+
 =item B<ambiguous> => "narrow" or "wide"
 
 Tells how to treat Unicode East Asian ambiguous characters.  Default
